@@ -7,9 +7,10 @@
 #'
 #' @docType package
 #' @name geouy
+#' @aliases geouy-package
 NULL
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
 if (getRversion() >= "2.15.1") utils::globalVariables(
-  c(".", "label", "link", "localidad", "lat", "lon")
-  )
\ No newline at end of file
+  c(".", "label", "link", "localidad", "lat", "lon", "all_of")
+  )
